@@ -17,12 +17,12 @@ def set_to_output(address):
 def pl_switch(address, value):
     if value not in ["on", "off"]:
         raise ValueError("Switch value must be 'on' or 'off'")
-
+    address = int(address)
     validate_address(address)
 
     if not is_output(address):
         logger.warning("GPIO%s is not OUTPUT configured, changing it ti OUTPUT" % address)
-        set_to_output(instance.did)
+        set_to_output(address)
 
 
     RPIO.output(address, value == "on")
